##  Using the SBOM Explorer
To access the SBOM explorer, on the navigation bar, choose More > Software Bill of Materials. Here, you find a list of all open-source libraries identified across your IT landscape. You can search within this list, apply filters from the drop-down menu at the top, and sort the columns by clicking on the column titles. For example, using the filter function, you can assess license risks by filtering for unpermitted licenses or quickly locate items with known risks through the search function.
Select any item in the list to expand the row and view its sub-components. Clicking on an item opens a pane on the right, providing more details such as license information, version specifics, dependent microservices, associated teams, related applications, and more. This allows you to quickly assess the blast radius and identify which parts of your IT system are at risk during cybersecurity incidents. You can filter items by package manager and namespace, enabling you to view the use of components company-wide and plan your roadmap.
![Using Software Bill of Materials](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e893e7a4410148935a283bf464d5d_LowRes.gif)
Using the SBOM Explorer
YesNo
Send
